<img src="https://www.lsstcorporation.org/lincc/sites/default/files/PastedGraphic-8.png" width="300" height="100">

# HiPSCat

[![Template](https://img.shields.io/badge/Template-LINCC%20Frameworks%20Python%20Project%20Template-brightgreen)](https://lincc-ppt.readthedocs.io/en/latest/)

![GitHub release (latest SemVer)](https://img.shields.io/github/v/release/astronomy-commons/hipscat)
![GitHub Workflow Status](https://img.shields.io/github/actions/workflow/status/astronomy-commons/hipscat/testing-and-coverage.yml)
![Read the Docs](https://img.shields.io/readthedocs/hipscat)

## Hierarchical Progressive Survey Catalog

A HiPSCat catalog is a partitioning of objects on a sphere. Its purpose is for 
storing data from large astronomy surveys, but could probably be used for other 
use cases where you have large data with some spherical properties.

Check out our [ReadTheDocs site](https://hipscat.readthedocs.io/en/latest/)
for more information on partitioning, installation, and contributing.

See related projects:

* HiPSCat Import ([on GitHub](https://github.com/astronomy-commons/hipscat-import))
  ([on ReadTheDocs](https://hipscat-import.readthedocs.io/en/latest/))
* LSDB ([on GitHub](https://github.com/astronomy-commons/lsdb)) 
  ([on ReadTheDocs](https://lsdb.readthedocs.io/en/latest/))

## Contributing

[![GitHub issue custom search in repo](https://img.shields.io/github/issues-search/astronomy-commons/hipscat?color=purple&label=Good%20first%20issues&query=is%3Aopen%20label%3A%22good%20first%20issue%22)](https://github.com/astronomy-commons/hipscat/issues?q=is%3Aissue+is%3Aopen+label%3A%22good+first+issue%22)

See the [contribution guide](https://hipscat.readthedocs.io/en/latest/guide/contributing.html)
for completed installation instructions and contribution best practices.

## Acknowledgements

LINCC Frameworks is supported by Schmidt Futures, a philanthropic initiative
founded by Eric and Wendy Schmidt, as part of the Virtual Institute of 
Astrophysics (VIA).
